// Add event listeners after the DOM has fully loaded
document.addEventListener('DOMContentLoaded', function () {
  setupNewsContainer(); // Initialize the news container
  displayNewsArticles('/data/meldungen.yml'); // Load and display news articles from YAML file
});

// Initializes the container that will hold news articles
function setupNewsContainer() {
  const container = document.getElementById('meldungen-container');
  // Clear the existing container content and set up an unordered list without bullets
  container.innerHTML = '<ul id="news-list" style="list-style-type: none;"></ul>';
}

// Asynchronously fetches a YAML file from the specified URL
async function fetchYamlFile(url) {
  try {
    // Attempt to fetch the YAML file
    const response = await fetch(url);
    // Throw an error if the fetch was unsuccessful
    if (!response.ok) {
        const list = document.getElementById('news-list');
        list.innerHTML = '<li style="padding-top:1rem;">Zur Zeit gibt es keine konkreten Meldungen/Einschränkungen.</li>';
        throw new Error(`HTTP error! status: ${response.status}`);
    }
    // Convert the YAML text response to a JavaScript object
    const yamlContent = await response.text();
    return jsyaml.load(yamlContent);
  } catch (error) {
    // Log the error if fetching or processing failed
    console.error('Error fetching YAML file:', error);
  }
}

// Filters and sorts news articles by date, starting with the one closest to today
function filterAndSortNewsArticlesByDate(newsArticles, today) {
  return newsArticles
    .filter(article => new Date(article.date) >= today)
    .sort((a, b) => new Date(a.date) - new Date(b.date));
}

// Generates HTML content for displaying news articles
function generateHtmlContent(newsArticles) {
  const list = document.getElementById('news-list');

  // Display a placeholder if no news articles are available
  if (newsArticles.length === 0) {
    list.innerHTML = '<li style="padding-top:1rem;">Zur Zeit gibt es keine konkreten Meldungen/Einschränkungen.</li>';
  } else {
    // Loop through each article and append its content to the list
    newsArticles.forEach((article, index) => {
        const articleDate = new Date(article.date);
        const germanFormattedDate = articleDate.toLocaleDateString('de-DE', {
            weekday: 'long', year: 'numeric', month: 'long', day: 'numeric'
        });
        const visibilityClass = index < 1 ? '' : 'extra'; // Control visibility for additional articles
        list.innerHTML += `<li class="${visibilityClass}">
                                <h2>${article.title}</h2>
                                <p><strong>Datum: ${germanFormattedDate}</strong></p>
                                <p>${article.description}</p>
                            </li>`;
    });
    // Append control buttons for more articles if necessary
    // appendControlButtons(newsArticles.length > 3);
  }
}

// Appends buttons to show more or fewer articles
function appendControlButtons(showMore) {
  const container = document.getElementById('meldungen-container');
  // Add 'More' and 'Less' buttons, showing the 'More' button only if needed
  container.innerHTML += `<button id="more-btn" onclick="showMoreArticles()" ${showMore ? '' : 'style="display:none;"'}>Mehr anzeigen</button>
                          <button id="less-btn" onclick="showFewerArticles()" style="display:none;">Weniger anzeigen</button>`;
}

// Shows additional articles and toggles visibility of control buttons
function showMoreArticles() {
  // Remove the 'extra' class to display all articles
  document.querySelectorAll('.extra').forEach(el => el.classList.remove('extra'));
  document.getElementById('more-btn').style.display = 'none';
  document.getElementById('less-btn').style.display = 'block';
}

// Hides additional articles and toggles visibility of control buttons
function showFewerArticles() {
  const articles = document.querySelectorAll('#news-list li');
  // Add the 'extra' class to hide articles beyond the initial visible set
  articles.forEach((el, index) => {
      if (index >= 1) el.classList.add('extra');
  });
  document.getElementById('more-btn').style.display = 'block';
  document.getElementById('less-btn').style.display = 'none';
}

// Displays news articles by fetching them, filtering, sorting, and rendering the content
async function displayNewsArticles(url) {
  const today = new Date();
  today.setHours(0, 0, 0, 0); // Reset the time part to start from the beginning of the day

  // Fetch and process articles
  const newsArticles = await fetchYamlFile(url);
  const filteredSortedArticles = filterAndSortNewsArticlesByDate(newsArticles, today);
  generateHtmlContent(filteredSortedArticles);
}
